/* 	CreateProjects.js 
	Script for BrainVoyager QX 2.2
	By Rainer Goebel 1995-2009
	Modified for BVQX 2.1 (2009), for BrainVoyager 20 (2019).
*/

var ObjectsRawDataPath = BrainVoyager.BrowseDirectory("Please select the path to the BrainVoyager sample data");//"/Users/BVuser/Data/ObjectsDicomGSG/";
var DTIDataPath = BrainVoyager.BrowseDirectory("Please select the path to the BrainVoyager DWI sample data");//"/Users/BVuser/Data/Human31dir/";
var OtherDataPath = BrainVoyager.BrowseDirectory("Please select the path to the data");//"/Users/BVuser/Data/testdata/IMA_files/";

/* This is the code being directly executed, only uncommented functions are invoked */
// now create the projects
BrainVoyager.PrintToLog("Create FMR project...");
Create_FMR_Project();
BrainVoyager.PrintToLog("Create mosaic FMR project...");
Create_Mosaic_FMR_Project();
BrainVoyager.PrintToLog("Create VMR project...");
Create_VMR_Project();
BrainVoyager.PrintToLog("Create DMR project...");
Create_DMR_Project();
BrainVoyager.PrintToLog("Create AMR project...");
Create_AMR_Project();
 
/* Project properties:
TR (property)
	set via: docFMR.TR = 2000;
InterSliceTime (property)
NrOfVolumes (property)
PixelSizeOfSliceDimX (property)
PixelSizeOfSliceDimY (property)
InterSliceTime (property)
SliceThickness  (property)
GapThickness  (property)
VoxelResolutionVerified (property)
TimeResolutionVerified (property)
FileNameOfPreprocessdFMR (property)
	obtain via: var newname = docFMR.FileNameOfPreprocessdFMR;
*/

/* The functions below are only executed when invoked */

// for non-mosaic EPI data
function Create_FMR_Project() 
{
    var firstfilename = BrainVoyager.BrowseFile("Please select the first file", "*.dcm");// OtherDataPath + "Subj1-0007-0001-00001.dcm";
 	var docFMR = BrainVoyager.CreateProjectFMR( "DICOM", firstfilename, 1, 0, true, 32, "untitled", false, 64, 64, 2, OtherDataPath);
	docFMR.SaveAs("NonMosaicDICOM_SCRIPT.fmr");
	docFMR.Close();
}

// for mosaic EPI data
function Create_Mosaic_FMR_Project()
{
BrainVoyager.PrintToLog(ObjectsRawDataPath + "BetSog_20040312_Goebel_C2 -0003-0001-0001.dcm");
    var docFMR = BrainVoyager.CreateProjectMosaicFMR("DICOM", ObjectsRawDataPath + "/" + "BetSog_20040312_Goebel_C2 -0003-0001-0001.dcm", 252, 2, true, 25, "untitled-", false, 320, 320, 2, ObjectsRawDataPath, 1, 64, 64 );
    docFMR.SaveAs( ObjectsRawDataPath + "CG_OBJECTS_SCRIPT.fmr" ); // added path
    docFMR.Close();
}

// for anatomical data
function Create_VMR_Project() 
{
      var docVMR = BrainVoyager.CreateProjectVMR( "DICOM", ObjectsRawDataPath + "/" + "BetSog_20040312_Goebel_C2 -0002-0001-0001.dcm", 192, false, 256, 256, 2 );
      docVMR.SaveAs( ObjectsRawDataPath + "CG_3DT1MPR_SCRIPT.vmr" ); // added path
	docVMR.Close();
}

// for DWI data
function Create_DMR_Project() 
{
	var docDMR = BrainVoyager.CreateProjectDMR("DICOM", DTIDataPath + "/" + "pimpul_070907_dti -0007-0001-00001.dcm", 31, 0, true, 75, "human31dir", false, 128, 128, 2, DTIDataPath);
	docDMR.SaveAs(DTIDataPath  + "/" + "HUMAN31DIR_SCRIPT.dmr");
	docDMR.TR = 8900;
	docDMR.InterSliceTime = 118;
	docDMR.TimeResolutionVerified = true;
	docDMR.Save();
	docDMR.Close();
}

// for localizers, etc.
function Create_AMR_Project()
{
      var docAMR = BrainVoyager.CreateProjectAMR( "DICOM", ObjectsRawDataPath  + "/" + "BetSog_20040312_Goebel_C2 -0001-0001-0001.dcm", 3, false, 256, 256, 2 );
      docAMR.SaveAs(ObjectsRawDataPath  + "/" + "CG_SLICELOCALIZER_SCRIPT.amr");
	docAMR.Close();
}

