
/* 	CreateVDWfiles.qs
	Script to create VDW files (normalised diffusion weighted)
*/

/* This information is used in the functions */
//	Setting hardcoded paths:
/*    var DTIDataPath 			= "/Users/BVuser/Data/Human31dir/";
	var nameDMR 				= DTIDataPath + "HUMAN31DIR_SCRIPT.dmr";
	var nameVMRinNative 		= DTIDataPath +"human.vmr";
	var nameVMRinAcpc			= DTIDataPath +"human_ACPC.vmr";
	var nameVMRinTal 			= DTIDataPath +"human_TAL.vmr";
	var nameIAfile 				= DTIDataPath + "HUMAN31DIR_SCRIPT-TO-human_IA.trf";
	var nameFAfile 				= DTIDataPath + "HUMAN31DIR_SCRIPT-TO-human_FA.trf";
	var nameACPCfile 			= DTIDataPath + "human_ACPC.trf";
	var nameTALfile 			= DTIDataPath + "human_ACPC.tal"; 
 */
    // Setting paths via file selection dialog:
    var DTIDataPath 			= BrainVoyager.BrowseDirectory("Please select the directory with DWI data") + "/";
    var nameDMR 				= BrainVoyager.BrowseFile("Please select the DMR file", "*.dmr");
    var nameVMRinNative 		= BrainVoyager.BrowseFile("Please select the native VMR file", "*.vmr");
    var nameVMRinAcpc			= BrainVoyager.BrowseFile("Please select the VMR file in AC-PC space", "*ACPC.vmr");
    var nameVMRinTal 			= BrainVoyager.BrowseFile("Please select the VMR file in Talairach space", "*TAL.vmr");
    var nameIAfile 				= BrainVoyager.BrowseFile("Please select the initial alignment file", "*IA.trf");
    var nameFAfile 				= BrainVoyager.BrowseFile("Please select the fine alignment file", "*FA.trf");
    var nameACPCfile 			= BrainVoyager.BrowseFile("Please select the AC-PC transformation file", "*ACPC.trf");
    var nameTALfile 			= BrainVoyager.BrowseFile("Please select the Talairach landmarks file", "*.tal");

	var today 					= new Date();
	var nameVDWinNative			= DTIDataPath + "HUMAN31DIR_SCRIPT_NATIVE.vdw";
	var nameVDWinAcpc			= DTIDataPath + "HUMAN31DIR_SCRIPT_ACPC.vdw";
	var nameVDWinTal			= DTIDataPath + "HUMAN31DIR_SCRIPT_TAL.vdw";
	var dataType                = 2; // integer 2-byte format: 1 or in float format: 2.
	var resolution 				= 3; // one of 1, 2 or 3 mm^2
	var interpolation 			= 1;
	var threshold 				= 100;

/* 	This code is executed when clicking 'Run'
	If an error occurs, it is printed to the BrainVoyager Log tab
*/
	BrainVoyager.ShowLogTab();
	BrainVoyager.PrintToLog("Start creating VDWs...");
	try {
		CreateVDWinNativeSpace();
		CreateVDWinAcpcSpace();
		CreateVDWinTalSpace();
	} catch (e) {
		BrainVoyager.PrintToLog("Error: " + e);
	}

/* These functions are invoked from the section above */
function CreateVDWinNativeSpace() {

	BrainVoyager.TimeOutMessageBox("This function creates a VDW file in native space...", 5);
	var vmr = BrainVoyager.OpenDocument(nameVMRinNative);
	BrainVoyager.PrintToLog("Start creating VDW in native space...");
	vmr.ExtendedTALSpaceForVTCCreation = false; // this is true or false
	var success = vmr.CreateVDWInVMRSpace(nameDMR, nameIAfile, nameFAfile, nameVDWinNative, dataType, resolution, interpolation, threshold);
	if (success) {
		BrainVoyager.PrintToLog("Created VDW: " + nameVDWinNative);
	} else {
		BrainVoyager.PrintToLog("VDW creation did not succeed.");
	}
 	vmr.Close();
}

function CreateVDWinAcpcSpace() {

	BrainVoyager.TimeOutMessageBox("This function creates a VDW file in AC-PC space...", 5);
	var vmr = BrainVoyager.OpenDocument(nameVMRinAcpc);
	BrainVoyager.PrintToLog("Start creating VDW in AC-PC space...");
	vmr.ExtendedTALSpaceForVTCCreation = false; // this is true or false
	var success = vmr.CreateVDWInACPCSpace(nameDMR, nameIAfile, nameFAfile, nameACPCfile, nameVDWinAcpc, dataType, resolution, interpolation, threshold);
	if (success) {
		BrainVoyager.PrintToLog("Created VDW: " + nameVDWinAcpc);
	} else {
		BrainVoyager.PrintToLog("VDW creation did not succeed.");
	}
 	vmr.Close();
}

function CreateVDWinTalSpace() {

	BrainVoyager.TimeOutMessageBox("This function creates a VDW file in Talairach space...", 5);
	var vmr = BrainVoyager.OpenDocument(nameVMRinTal);
	BrainVoyager.PrintToLog("Start creating VDW in Talairach space...");
	vmr.ExtendedTALSpaceForVTCCreation = false; // always set this property
	var success = vmr.CreateVDWInTALSpace(nameDMR, nameIAfile, nameFAfile, nameACPCfile, nameTALfile, nameVDWinTal, dataType, resolution, interpolation, threshold);
	if (success) {
		BrainVoyager.PrintToLog("Created VDW: " + nameVDWinTal);
	} else {
		BrainVoyager.PrintToLog("VDW creation did not succeed.");
	}
 	vmr.Close();
}


