/* 	ExperimentalDesign_BV21_newGSGdata.js
	Script for BrainVoyager QX 2.1, adapted for BrainVoyager 21+ (June 2019) and new GSG data (24-08-19)
*/
/* Declarations */
var vmrname = BrainVoyager.BrowseFile("Please select the VMR file", "*.vmr"); // for all functions (*.sdm and *.mdm creation)
var ObjectsRawDataPath = BrainVoyager.BrowseDirectory("Please select the directory of the data") + "/";
var vtcname = BrainVoyager.BrowseFile("Please select the VTC file", "*.vtc"); // for single subject (*.prt and *.sdm)
var RFXDataPath = BrainVoyager.BrowseDirectory("Please select the directory of the random effects data") + "/";
//Users/BVuser/Data/Exercise_RFX_ANOVA/";

CreateDesignMatrix(); 
CreateMultiStudyDesignMatrix();

function CreateDesignMatrix()
{
	BrainVoyager.PrintToLog("Create single subject design matrix...");
	var doc = BrainVoyager.OpenDocument( vmrname ) ;
//ObjectsRawDataPath + "sub-01_ses-04_acq-nondistorted_T1w.vmr" );
	doc.LinkVTC( vtcname ); 
	doc.LinkStimulationProtocol(ObjectsRawDataPath + "s01_sess4_blocked_vol.prt");
	doc.ClearDesignMatrix();
//	doc.AutoAddConstantPredictor();

	doc.AddPredictor("Faces_LVF");
	doc.SetPredictorValuesFromCondition("Faces_LVF", "Faces_LVF", 1.0);
	doc.ApplyHemodynamicResponseFunctionToPredictor("Faces_LVF");
 
	doc.AddPredictor("Houses_RVF");
	doc.SetPredictorValuesFromCondition("Houses_RVF", "Houses_RVF", 1.0);
	doc.ApplyHemodynamicResponseFunctionToPredictor("Houses_RVF");

	doc.AddPredictor("Faces_CVF");
	doc.SetPredictorValuesFromCondition("Faces_CVF", "Faces_CVF", 1.0);
	doc.ApplyHemodynamicResponseFunctionToPredictor("Faces_CVF");

	doc.AddPredictor("Houses_LVF");
	doc.SetPredictorValuesFromCondition("Houses_LVF", "Houses_LVF", 1.0);
	doc.ApplyHemodynamicResponseFunctionToPredictor("Houses_LVF");

	doc.AddPredictor("Faces_RVF");
	doc.SetPredictorValuesFromCondition("Faces_RVF", "Faces_RVF", 1.0);
	doc.ApplyHemodynamicResponseFunctionToPredictor("Faces_RVF");

	doc.AddPredictor("Houses_CVF");
	doc.SetPredictorValuesFromCondition("Houses_CVF", "Houses_CVF", 1.0);
	doc.ApplyHemodynamicResponseFunctionToPredictor("Houses_CVF");
 
	// You can also set any value at any time point (interval), here we define a linear trend predictor
/*	doc.AddPredictor("Linear Trend");
	for(i = 1; i<= doc.NrOfVolumes; i++)
	{
		value = 0.1*i;
		doc.SetPredictorValues("Linear Trend", i, i, value);
	}
	doc.ScalePredictorValues("Linear Trend", 1.0, false);
*/
//doc.AutoAddConstantPredictor(); 
	BrainVoyager.CurrentDirectory = ObjectsRawDataPath; //"/Users/BVuser/Data/ObjectsDicomGSG/");
	doc.SaveSingleStudyGLMDesignMatrix("FacesHousesDesignMatrix.sdm");
}

function CreateMultiStudyDesignMatrix()
{
	BrainVoyager.PrintToLog("Create multi subject design matrix...");
	var doc = BrainVoyager.OpenDocument(RFXDataPath + "Average_Tal.vmr");
	doc.ClearMultiStudyGLMDefinition();
	var subjName;
	var nrOfSubjects = 17;
	for (i=0; i<nrOfSubjects; i++) {
		subjName = RFXDataPath + "Sub" + (i+1) + "_run1_SCSAI2_3DMCTS_LTR_THPFFT3c_TAL.vtc"; // create subject name
		doc.AddStudyAndDesignMatrix(subjName, RFXDataPath + "run1_SCSAI2_3DMCTS_LTR_THPFFT3c_TAL.sdm"); // now use subject name and always same protocol
	}
	doc.SaveMultiStudyGLMDefinitionFile(RFXDataPath + "MultiStudy_FROMSCRIPT.mdm");
}
