//
// This script shows how to prepare and run (rigid) CBA including group mesh/curvature map visualization.
//
//  Created by Rainer Goebel, May 2013, updated for BV21 June 2019
//

var CBAfiledir = BrainVoyager.BrowseDirectory("Please select the directory with CBA files");
CreateSphereFromFoldedMesh();
MapSphereGetCurvature();
RunRigidCBAStep();
RunFullCBA();

function CreateSphereFromFoldedMesh()
{
	var ok;    
	var docVMRname = BrainVoyager.BrowseFile("Please select a VMR", "*.vmr");
	var docVMR = BrainVoyager.OpenDocument(docVMRname);//ActiveDocument;
	if (docVMR == undefined) return;
	// It is assumed that a folded "*_RECOSM.srf" mesh is available (e.g. loaded)
	var docSRFname = BrainVoyager.BrowseFile("Please select a SRF", "*RECOSM.srf");
    	docVMR.LoadMesh(docSRFname);//
	var mesh = docVMR.CurrentMesh;
	 if (mesh == undefined) BrainVoyager.PrintToLog("Mesh is undefined");
	mesh.MorphingUpdateInterval = 50;
	BrainVoyager.PrintToLog("CalculateCurvatureCBA");
	mesh.CalculateCurvatureCBA();
	BrainVoyager.PrintToLog("SmoothCurrentMap");
	mesh.SmoothCurrentMap(5);
	BrainVoyager.PrintToLog("CalculateCurvatureCBA");
	mesh.MeshScene.UpdateSurfaceWindow();
	BrainVoyager.PrintToLog("InflateMeshToSphere");
	mesh.InflateMeshToSphere(800);
	BrainVoyager.PrintToLog("CorrectInflatedSphereMesh");
	mesh.CorrectInflatedSphereMesh(3000);
	BrainVoyager.PrintToLog("mesh.FileName: " + mesh.FileName);
	var new_name = makeNameWithInfix(mesh.FileName, "_SPHERE"); 
	BrainVoyager.PrintToLog(new_name);
	mesh.SaveAs(new_name);
	BrainVoyager.PrintToLog("SaveAs");
	BrainVoyager.PrintToLog("Saving " +new_name);
}

function MapSphereGetCurvature()
{
	var ok;
	var docVMR = BrainVoyager.ActiveDocument; if(docVMR == undefined) return;
	var meshScene = docVMR.MeshScene; if(meshScene == undefined) return;
	var mesh = meshScene.CurrentMesh; if(mesh == undefined) return;

	// we assume created sphere mesh (see "CreateSphereFromFoldedMesh" above) is available as current mesh (created or loaded) AND available on disk (since it is reloaded)
	var sphere_mesh_name =  mesh.FileName;
	// we need name of folded original mesh below - here we assume that name is same as SPHERE mesh but instead of "SPHERE" has "RECOSM" at end of name
	var folded_mesh_name = makeNameWithInfix(sphere_mesh_name, "_RECOSM");  

	meshScene.SphereResolutionCBA = 1; // 1 -> standard resolution (default), 2 -> low resolution, 3 -> high resolution
	var saved_ssm_file          = meshScene.MapSphereMeshFromStandardSphere();
	var saved_foldedSPH_file = meshScene.SetStandardSphereToFoldedMesh(folded_mesh_name);
	mesh = meshScene.CurrentMesh;
	var saved_curvature_file  = mesh.CreateMultiScaleCurvatureMap(2, 7, 20, 40);
	// the obtained curvature file (automatically saved) is needed for CBA - store in array, one for each subject (per hemisphere)
	BrainVoyager.PrintToLog("Curvature file: " + saved_curvature_file);
}

function RunRigidCBAStep()
{
	var ok;
	//var docVMR = BrainVoyager.ActiveDocument; 
	var docVMRname = BrainVoyager.BrowseFile("Please select a VMR", "*.vmr");

	BrainVoyager.PrintToLog("Open VMR: " + docVMRname);
	var docVMR = BrainVoyager.OpenDocument(docVMRname);
	if (docVMR == undefined){
		BrainVoyager.PrintToLog("Could not find VMR");
		return;
	}
	BrainVoyager.PrintToLog("Get mesh scene...");
	var meshScene = docVMR.CreateMeshScene();// before BV21: GetMeshScene(); //docVMR.MeshScene; 
	if (meshScene == undefined) {
		BrainVoyager.PrintToLog("Could not get mesh scene");
		return;
	}
	// the mesh for rigid alignment must be a sphere (SPH file)
	// to ensure that we have a sphere mesh, we can create one
	BrainVoyager.PrintToLog("Create standard sphere mesh... (SPH)");
	meshScene.CreateStandardSphereMesh();
	var mesh = meshScene.CurrentMesh;

	BrainVoyager.PrintToLog("Clear group CBA curvature files....");
	meshScene.ClearGroupCBACurvatureFiles();
	var NSubjects = 5;
	var CurvatureFile, TargetCurvatureFile;
	for(i=0; i<NSubjects; i++) // loop over subjects (per hemisphere)
	{
		// for demonstration, we simply hard-code files here - better to use/prepare array
/*		if(i == 0) CurvatureFile = BrainVoyager.PathToSampleData + "CortexBasedAlignment/AA/AA_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if(i == 1) CurvatureFile = BrainVoyager.PathToSampleData + "CortexBasedAlignment/MR/MR_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if(i == 2) CurvatureFile = BrainVoyager.PathToSampleData + "CortexBasedAlignment/PD/PD_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if(i == 3) CurvatureFile = BrainVoyager.PathToSampleData + "CortexBasedAlignment/RM/RM_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if(i == 4) CurvatureFile = BrainVoyager.PathToSampleData + "CortexBasedAlignment/SG/SG_TAL_LH_RECOSM_SPH_CURVATURE.smp";
*/		
		if(i == 0) CurvatureFile = CBAfiledir + "/sub_AA/AA_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if(i == 1) CurvatureFile = CBAfiledir + "/sub_MR/MR_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if(i == 2) CurvatureFile = CBAfiledir + "/sub_PD/PD_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if(i == 3) CurvatureFile = CBAfiledir + "/sub_RM/RM_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if(i == 4) CurvatureFile = CBAfiledir + "/sub_SG/SG_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		
		BrainVoyager.PrintToLog("Adding curvature files, iteration " + toString(i+1) + ", curvature file: " + CurvatureFile);
		ok = meshScene.AddCurvatureFileForGroupCBA(CurvatureFile);
		if(!ok) // provided file not found
			return;

		if(i == 0) TargetCurvatureFile = CurvatureFile; // we here use first case for rigid alignment target (any should be fine)
	}

	BrainVoyager.PrintToLog("Create spherical coordinates map from curvature file (SMP)..."); 
	var SphericalTargetCurvatureFile = mesh.CreateSphericalCoordinatesMapFromSMP(TargetCurvatureFile);

	BrainVoyager.PrintToLog("Spherical target curvature file: " + SphericalTargetCurvatureFile + "..."); 
	if (SphericalTargetCurvatureFile == "") {// we get empty string if it did not work
		BrainVoyager.PrintToLog("Rigid CBA did not work with spherical target curvature file " + SphericalTargetCurvatureFile);	
		return;
	}

	BrainVoyager.PrintToLog("Run rigid cortex based alignment..."); 
	ok = meshScene.RunRigidCBA(SphericalTargetCurvatureFile);
	// the result of rigid alignment is automatically saved in a ".rga" file that will be used by subsequent CBA when using same input curvature SMP files
}

function RunFullCBA()
{
	var ok;
	BrainVoyager.PrintToLog("Run full cortex based alignment..."); 
	var docVMR = BrainVoyager.ActiveDocument; if(docVMR == undefined) return;
	var meshScene = docVMR.CreateMeshScene(); if(meshScene == undefined) return; // creates surface window if not present
	meshScene.ClearGroupCBACurvatureFiles(); // if this is run after rigid-CBA, we would not strictly fill curvature SMP list again
	var NSubjects = 5;
	var CurvatureFile;
	for(i=0; i<NSubjects; i++) // loop over subjects (per hemisphere)
	{
		// for demonstration, we simply hard-code files here - better to use/prepare array
/*		if(i == 0) CurvatureFile = BrainVoyager.PathToSampleData + "CortexBasedAlignment/AA/AA_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if(i == 1) CurvatureFile = BrainVoyager.PathToSampleData + "CortexBasedAlignment/MR/MR_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if(i == 2) CurvatureFile = BrainVoyager.PathToSampleData + "CortexBasedAlignment/PD/PD_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if(i == 3) CurvatureFile = BrainVoyager.PathToSampleData + "CortexBasedAlignment/RM/RM_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if(i == 4) CurvatureFile = BrainVoyager.PathToSampleData + "CortexBasedAlignment/SG/SG_TAL_LH_RECOSM_SPH_CURVATURE.smp";
*/
		if (i == 0) CurvatureFile = CBAfiledir + "/sub_AA/AA_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if (i == 1) CurvatureFile = CBAfiledir + "/sub_MR/MR_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if (i == 2) CurvatureFile = CBAfiledir + "/sub_PD/PD_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if (i == 3) CurvatureFile = CBAfiledir + "/sub_RM/RM_TAL_LH_RECOSM_SPH_CURVATURE.smp";
		if (i == 4) CurvatureFile = CBAfiledir + "/sub_SG/SG_TAL_LH_RECOSM_SPH_CURVATURE.smp";		
		ok = meshScene.AddCurvatureFileForGroupCBA(CurvatureFile);
		if (!ok) {// provided file not found
			BrainVoyager.PrintToLog("File " + CurvatureFile + " not found");
			return;
		}
	}
	ok = meshScene.RunCBA(); 
	if (!ok) {
		BrainVoyager.PrintToLog("Cortex based alignment did not succeed.");
		return;
	}
	// these convenience functions can only be called after CBA (with internally stored set of .SRF, .SSM, .SMP file names):
	// create group curvature map indicating quality of alignment, saves also ".cal" file that can be used in CBA dialog
	ok = meshScene.CreateAverageCurvatureGroupMap(); 
	// create folded group average cortex using created alignment (SSM) files, saves also ".sal" file that can be used in CBA dialog
	// the function only works if names of folded SPH meshes can be derived from	curvature names by replacing trailing substring with "_RECOSM_SPH.srf" 
	ok = meshScene.CreateAverageFoldedGroupMesh();
}

function makeNameWithInfix(name, infix) {
	var fi = new QFileInfo(name);
	newname = getNewName(name, infix, "." + fi.completeSuffix());
	return newname;
}

function getNewName(name, infix, suffix) {
	var fi = new QFileInfo(name);
	var newname = fi.path() + "/" + fi.baseName() + infix + suffix;  
	return newname;
}
