//
// Example script showing how to run statistics with the new "mesh" object
// Feel free to adapt this script to your needs
//
//  Created by Rainer Goebel, May 2013, updated 20-08-2019
//

//var ObjectsRawDataPath = BrainVoyager.BrowseDirectory("Please select the directory with surface files");
var MTCname = BrainVoyager.BrowseFile("Please select the functional data on the mesh", "*.mtc"); 
BrainVoyager.PrintToLog("MTC name: " + MTCname);

// when calling this function, we assume a VMR and the desired mesh have been loaded already (see also other "Mesh..." scripts)
//
function PreprocessMTC()
{

	var docVMR = BrainVoyager.ActiveDocument;
	if (docVMR == undefined) {
		BrainVoyager.PrintToLog("Could not obtain access to anatomical file");
		return;
	}

	var mesh = docVMR.CurrentMesh;
	if (mesh == undefined) {
		BrainVoyager.PrintToLog("Could not obtain access to surface file");
		return;
	}
	var ok = mesh.LinkMTC(MTCname); 
	if (!ok) {
		BrainVoyager.PrintToLog("Could not link functional file " + MTCname);
		return;
	};

	BrainVoyager.PrintToLog("Spatial smoothing...");
	mesh.SpatialSmoothing(3);
	BrainVoyager.PrintToLog("Linear trend removal...");
	mesh.LinearTrendRemoval();
	BrainVoyager.PrintToLog("Temporal high pass filter...");
	mesh.TemporalHighPassFilterFFT(3);
	BrainVoyager.PrintToLog("Temporal low pass filter...");
	mesh.TemporalGaussianSmoothing(5, "Seconds");

	//	var PreprocessedMTCFileName = mesh.FileNameOfPreprocessdMTC;
	//	mesh.SaveMTC(PreprocessedMTCFileName);
	BrainVoyager.PrintToLog("Preprocessed .MTC: " + getNewNameWithInfix(MTCname, "_preprocessed"));	
	mesh.SaveMTC(getNewNameWithInfix(MTCname, "_preprocessed"));
}

function getNewNameWithInfix(name, infix) {
	var fi = new QFileInfo(name);
	newname = getNewName(name, infix, "." + fi.suffix());//fi.completeSuffix());
	return newname;
}

function getNewName(name, infix, suffix) {
	var fi = new QFileInfo(name);
	var newname = fi.path() + "/" + fi.baseName() + infix + suffix;  
	return newname;
}

PreprocessMTC();