//
// This script shows how a mesh can be smoothed and inflated.
// It is assumed that a "*_RECO.srf" mesh is available (e.g. loaded)
//
//  Created by Rainer Goebel, May 2013; checked for BV21 June 2019
//

MorphMesh();

function MorphMesh()
{
    var ok;
    var docVMR = BrainVoyager.ActiveDocument;
    if (docVMR == undefined) return;
    var mesh = docVMR.CurrentMesh;
    if (mesh == undefined) return;
    
    mesh.MorphingUpdateInterval = 25;
    //mesh.SmoothMesh(30, 0.07); // standard smoothing - mesh will shrink
    mesh.SmoothRecoMesh(50, 0.07); // special "high-frequency" smoothing
    //removing jags of reconstructed voxel borders without shrinking mesh
    mesh.CalculateCurvature();
    mesh.SmoothCurrentMap(5);
    mesh.MeshScene.UpdateSurfaceWindow();
    var new_name = makeNameWithInfix(mesh.FileName, "_SM");
    mesh.SaveAs(new_name);
    mesh.InflateMesh(500, 0.8, ""); // if "" used for 3rd param (area reference mesh),
    // the current mesh at the moment the fn is called is
    // used to calculate ref mesh area
}

function makeNameWithInfix(name, infix) {
	var fi = new QFileInfo(name);
    newname = getNewName(name, infix, "." + fi.completeSuffix());
    return newname;
}

function getNewName(name, infix, suffix) {
    var fi = new QFileInfo(name);
    var newname = fi.path() + "/" + fi.baseName() + infix + suffix;
    return newname;
}
