// New script commands in v2.8.4 support VOI processing including running single-study GLM analyses
// Rainer Goebel 2014, adapted for BV21 June 2019

BrainVoyager.ShowLogTab();

var vmrname = BrainVoyager.BrowseFile("Please select the anatomical file", "*.vmr"); // BrainVoyager.ActiveDocument;
var docVMR = BrainVoyager.OpenDocument(vmrname);
//var curFolder = BrainVoyager.CurrentDirectory;
var VOIFile = BrainVoyager.BrowseFile("Please select the VOI file", "*.voi"); //BrainVoyager.PathToSampleData + "ObjectsDicomGSG/Visual.voi";
BrainVoyager.PrintToLog("VOI file: " + VOIFile);
var ok = docVMR.LoadVOIFile(VOIFile);
if(!ok) {
	BrainVoyager.PrintToLog("Could not open .VOI file");
	return;
}

var n_vois = docVMR.NrOfVOIs;
BrainVoyager.PrintToLog("No. of VOIs: " + n_vois);
for(i=0; i<n_vois; i++) 
{
	var voi_name = docVMR.GetNameOfVOI(i);
	BrainVoyager.PrintToLog("Name of VOI " + (i+1) + ": " + voi_name);
}

docVMR.HideAllVOIs();
// select all vois for display
for(i=0; i<n_vois; i++) 
	docVMR.SelectVOI(i); // VOI index is 0-based!

docVMR.ShowSelectedVOIs();
var vtcname = BrainVoyager.BrowseFile("Please select the design matrix file", "*.vtc"); 
docVMR.LinkVTC(vtcname);
var sdmname = BrainVoyager.BrowseFile("Please select the design matrix file", "*.sdm"); // BrainVoyager.PathToSampleData + "ObjectsDicomGSG/SingleStudy.sdm"
docVMR.LoadSingleStudyGLMDesignMatrix(sdmname);
var n_preds = docVMR.NrOfPredictorsInSingleStudyDM;
var n_points = docVMR.NrOfTimePointsInSingleStudyDM;

docVMR.PrepareROIContrasts(n_preds); // param: number of predictors
docVMR.AddROIContrast("Left vs Baseline", "1 0 0 0");
docVMR.AddROIContrast("Right vs Baseline", "0 1 0 0");
docVMR.AddROIContrast("Left vs Right", "1 -1 0 0");

// param 1: VOI index (0-based)
// param 2: time course normalization, 0 -> none, 1 -> percent change, 2 -> z, 3 -> z in baseline periods
// param 3: serial correlation correction, 0 -> none, 1 -> with AR(1) model, 2 -> with AR(2) model  
docVMR.ComputeSingleStudyGLMForVOI(0, 1, 2);

// Main stats for contrasts are accessible (full GLM/contrast results are printed in Log)
for(i=0; i<docVMR.NrOfROIContrasts; i++) {
	var c_name = docVMR.GetNameOfROIContrast(i);
	var c_t = docVMR.GetTValueOfROIContrast(i);
	var c_p = docVMR.GetPValueOfROIContrast(i);

	BrainVoyager.PrintToLog("VOI-GLM result for contrast " + (i+1) + " (" + c_name + "): t = " + c_t + "  p = " + c_p);
}

// The GLM betas can also be retrieved
for(i=0; i<n_preds; i++) {
	var b_name = docVMR.GetBetaNameOfROIGLM(i);
	var b_val = docVMR.GetBetaValueOfROIGLM(i);
	BrainVoyager.PrintToLog("VOI-GLM beta " + (i+1) + " (" + b_name + "): " + b_val);
}
