
//
// Example script for preprocessing a FMR document (single run)
// Feel free to adapt this script to your needs
//
//  Created by Rainer Goebel, last modified November 03 2005
//  Modified for QX 2.1, August 31 2009, February 3 2010, for BrainVoyager 21 April 11 2019 HB
//

//var ObjectsRawDataPath = "/Users/BVuser/Data/ObjectsDicomGSG/";
//var MocoISAPath = "/Users/BVuser/Data/testdata/moco_isa/";

/* This code will be executed when clicking 'Run' */
//Preprocess_FMR();
//MotionCorrectionISA();

var fmrname = BrainVoyager.BrowseFile("Please select the FMR file", "*.fmr");
MotionCorrection(fmrname, 1);

/* These functions can be invoked */
function Preprocess_FMR()
{
    var ret = BrainVoyager.TimeOutMessageBox( "This script function will run standard FMR preprocessing steps.\n\nYou can cancel this script by pressing the 'ESCAPE' key.", 8);
    if( !ret ) return;
 
	var newgsgdata = true;
    // Create a new FMR or open a previously created one.  Here we open the "CG_OBJECTS_SCRIPT.fmr" file
    var docname = BrainVoyager.BrowseFile("Please select the FMR file", "*.fmr"); // makes filedialog appear; for alternative, comment line 26 and 27 and uncomment line 28
    var docFMR = BrainVoyager.OpenDocument(docname); // the file path and name are saved in the variable "docname"
//    var docFMR = BrainVoyager.OpenDocument(ObjectsRawDataPath  + "CG_OBJECTS_SCRIPT.fmr"); // hardcoded file paths
  
    // Set spatial and temporal parameters relevant for preprocessing
    // You can skip this, if you have checked that these values are set when reading the data
    // To check whether these values have been set already (i.e. from header), use the "VoxelResolutionVerified" and "TimeResolutionVerified" properties
    //
    if( !docFMR.TimeResolutionVerified )
    {
	docFMR.TR = 2000;
	if (newgsgdata) {
		docFMR.InterSliceTime = 31;
	} else {
		docFMR.InterSliceTime = 80; 
	}
	docFMR.TimeResolutionVerified = true;
    }
    if( !docFMR.VoxelResolutionVerified )
    {
	if (newgsgdata) {
		docFMR.PixelSizeOfSliceDimX = 2;
		docFMR.PixelSizeOfSliceDimY = 2;
		docFMR.SliceThickness = 2;
		docFMR.GapThickness = 0;
	} else {
		docFMR.PixelSizeOfSliceDimX = 3.5; 
		docFMR.PixelSizeOfSliceDimY = 3.5; 
		docFMR.SliceThickness = 3; 
		docFMR.GapThickness = 0.99; 
	}
	docFMR.VoxelResolutionVerified = true;
    }
 
    // We also link the PRT file, if available (if no path is specified, the program looks in folder of dcoument)
    docFMR.LinkStimulationProtocol( "CG_OBJECTS.prt" );
 
    // We save the new settings into the FMR file
    docFMR.Save();
 
    //
    // Preprocessing step 1: Slice time correction
    //
    ret = BrainVoyager.TimeOutMessageBox("Preprocessing step 1: Slice time correction.\n\nTo skip this step, press the 'ESCAPE' key.", 5);
    if(ret)
    {
	docFMR.CorrectSliceTiming( 1, 0 ); // First param: Scan order 0  -> Ascending,  1  -> Asc-Interleaved,  2  -> Asc-Int2,   10 -> Descending,  11 -> Desc-Int,  12 -> Desc-Int2
  // Second param: Interpolation method: 0 -> trilinear, 1 -> cubic spline, 2 -> sinc

  ResultFileName = docFMR.FileNameOfPreprocessdFMR;
  docFMR.Close();          // close input FMR
  docFMR = BrainVoyager.OpenDocument( ResultFileName );
 }
 //
 // Preprocessing step 2: 3D motion correction
 ret = BrainVoyager.TimeOutMessageBox("Preprocessing step 2: 3D motion correction.\n\nTo skip this step, press the 'ESCAPE' key.", 5);
 if(ret)
 {
  docFMR.CorrectMotion(1); // 1 is target volume. For more parameters, use CorrectMotionEx(); please see below for more motion correction functions
  ResultFileName = docFMR.FileNameOfPreprocessdFMR;  // the current doc (input FMR) knows the name of the automatically saved output FMR
  docFMR.Close();            // close input FMR
  docFMR = BrainVoyager.OpenDocument( ResultFileName ); // Open motion corrected file (output FMR) and assign to our doc var
 }
 //
 // Preprocessing step 3: Spatial Gaussian Smoothing    (not recommended for individual analysis with a 64x64 matrix)
 ret = BrainVoyager.TimeOutMessageBox("Preprocessing step 3: Spatial gaussian smoothing.\n\nTo skip this step, press the 'ESCAPE' key.", 5);
 if(ret)  {
  	docFMR.SpatialGaussianSmoothing( 4, "mm" );    // FWHM value and unit
  	ResultFileName = docFMR.FileNameOfPreprocessdFMR;
  	docFMR.Close();          // close input FMR
  	docFMR = BrainVoyager.OpenDocument( ResultFileName );
 }
 
 // Preprocessing step 4: Temporal High Pass Filter, includes Linear Trend Removal
 ret = BrainVoyager.TimeOutMessageBox("Preprocessing step 4: Temporal high-pass filter.\n\nTo skip this step, press the 'ESCAPE' key.", 5);
 if(ret) {
 	 docFMR.TemporalHighPassFilter( 3, "cycles" );
 	 ResultFileName = docFMR.FileNameOfPreprocessdFMR;
 	 docFMR.Close();           // close input FMR
 	 docFMR = BrainVoyager.OpenDocument( ResultFileName );
 }
 
 // Preprocessing step 5: Temporal Gaussian Smoothing  (not recommended for event-related data)
 ret = BrainVoyager.TimeOutMessageBox("Preprocessing step 5: Temporal gaussian smoothing.\n\nTo skip this step, press the 'ESCAPE' key.", 5);
 if (ret) {
	  docFMR.TemporalGaussianSmoothing( 10, "s" );
	  ResultFileName = docFMR.FileNameOfPreprocessdFMR;
	  docFMR.Close();           // close input FMR
	  docFMR = BrainVoyager.OpenDocument( ResultFileName );
 }
 
 // docFMR.Close() // you may want to close the final document, i..e to preprocess another run
}


//~~~~~~~~~~~ extra motion correction examples ~~~~~~~~~~~

function MotionCorrectionISA()
{
    var docname = BrainVoyager.BrowseFile("Please select the FMR file", "*.fmr"); // makes filedialog appear; for alternative, comment line 111 and 112 and uncomment line 113
    var docFMR = BrainVoyager.OpenDocument(docname); // the file path and name are saved in the variable "docname"
//	var docFMR = BrainVoyager.OpenDocument(MocoISAPath  + "FFA_localizer_2/series0003_SCLAI2.fmr"); // hardcoded version
//	docFMR.CorrectMotionTargetVolumeInOtherRun(MocoISAPath + "FFA_localizer_1/series0002_SCCAI2_3DMCT.fmr", 1 ); // intra-session alignment (ISA)
    var targetdocname = BrainVoyager.BrowseFile("Please select the target FMR file", "*.fmr");
    docFMR.CorrectMotionTargetVolumeInOtherRunEx(targetdocname, 1, 1, 1, 100, 0, 1 );
//  docFMR.CorrectMotionTargetVolumeInOtherRunEx(MocoISAPath + "FFA_localizer_1/series0002_SCCAI2_3DMCT.fmr", 1, 1, 1, 100, 0, 1 );// same method, more parameters
}

function MotionCorrection(fmrname, targetvolume)
{
	var docFMR = BrainVoyager.OpenDocument(fmrname);
 	docFMR.CorrectMotion(targetvolume);
 
 	// for intra-session motion correction use this command (with approprate file name):
    // docFMR.CorrectMotionTargetVolumeInOtherRun("run1.fmr", 1);
 
    var ResultFileName = docFMR.FileNameOfPreprocessdFMR;
 	docFMR.Close();
	docFMR = BrainVoyager.OpenDocument( ResultFileName );
}

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

